<?php
/**
 * header template
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
?>
<?php $inst = LEAPIN_Theme_Mod::get_instance(); ?>
<!doctype html>
<html <?php language_attributes(); ?> itemscope itemtype="https://schema.org/WebPage">

<head>
    <?php
    do_action('leapin_loc_top_of_head');
    ?>
    <meta charset="<?php bloginfo('charset'); ?>"/>

    <?php // force Internet Explorer to use the latest rendering engine available ?>
    <meta http-equiv="X-UA-Compatible" content="IE=edge">

    <!-- meta keyword is not used for web ranking anymore, so don't need to print it. -->
    <?php
    // meta keyword is not used in SEO.
    // Google - https://webmasters.googleblog.com/2009/09/google-does-not-use-keywords-meta-tag.html
    // Bing - https://blogs.bing.com/webmaster/2014/10/03/blame-the-meta-keyword-tag/
    ?>

    <?php // mobile meta (hooray!) ?>
    <meta name="HandheldFriendly" content="True">
    <meta name="MobileOptimized" content="320">
    <meta name="viewport" content="width=device-width, initial-scale=1"/>
    <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">

    <?php // wordpress head functions ?>
    <?php wp_head(); ?>
    <?php // end of wordpress head ?>

    <?php
    do_action('leapin_loc_end_of_head');
    ?>
</head>
<body <?php body_class(apply_filters('leapin_body_class', [])); ?>>
<?php
do_action('leapin_loc_top_of_body');

leapin_the_non_supported_ie_browser();
?>
<meta itemprop="accessibilityControl" content="fullKeyboardControl">
<meta itemprop="accessibilityControl" content="fullMouseControl">
<meta itemprop="accessibilityHazard" content="noFlashingHazard">
<meta itemprop="accessibilityHazard" content="noMotionSimulationHazard">
<meta itemprop="accessibilityHazard" content="noSoundHazard">
<meta itemprop="accessibilityAPI" content="ARIA">

<?php
    echo LEAPIN_Header::get_mobile_nav();
?>
<div class="mobile-nav__overlay"></div>
<div id="container">
    <header id="header" class="header" itemscope itemtype="http://schema.org/WPHeader">
        <?php
        $transparent = $inst->get(LEAPIN_IDs::$leapin_header_transparent, false);
        $transparent_header = $transparent && is_front_page() ? ' transparent' : '';
        ?>
        <div id="inner-header" class="cf inner-header<?php echo $transparent_header ?>">
            <?php echo LEAPIN_Header::get_main_nav('fixed'); ?>
            <?php echo LEAPIN_Header::get_main_nav(); ?>
            <?php $theme_location = 'secondary-nav';
            if (has_nav_menu($theme_location)): ?>
                <?php
                $display_secandary_nav_for_login_user = $inst->get(LEAPIN_IDs::$leapin_secondary_menu_display_for_login_user, false);
                if (($display_secandary_nav_for_login_user && is_user_logged_in())
                    || !$display_secandary_nav_for_login_user): ?>
                    <nav id="secondary-nav" aria-label="Navigation" itemscope
                         itemtype="http://schema.org/SiteNavigationElement">
                        <?php
                        if ($inst->get(LEAPIN_IDs::$leapin_secondary_menu_type, LEAPIN_Theme_Mod::$default_leapin_secondary_menu_type)
                            == 'rich'):?>
                            <?php LEAPIN_Navigation::the_menu($theme_location, 3); ?>
                        <?php else:
                            wp_nav_menu(array(
                                'container' => false,                           // remove nav container
                                'container_class' => 'secondary cf',                 // class of container (should you choose to use it)
                                'menu_class' => 'nav secondary-nav simple cf',              // adding custom nav class
                                'theme_location' => $theme_location,                 // where it's located in the theme
                                'link_before' => '<span>',                            // before each link
                                'link_after' => '</span>',                             // after each link
                                'depth' => 3                                   // limit the depth of the nav
                            ));
                        endif; ?>
                        <?php if (leapin_is_mod_visible(LEAPIN_IDs::$leapin_secondary_menu_hide_sns)): ?>
                            <div class="sns-links">
                                <?php echo LEAPIN_General_Settings::get_sns_links(); ?>
                            </div>
                        <?php endif; ?>
                    </nav>
                <?php endif; ?>
            <?php endif; ?>

        </div>

    </header>
    <div id="barba-wrapper" aria-live="polite">
        <?php
        $barba_ns = 'other';
        if (is_home() || is_front_page()) {
            $barba_ns = 'home';
        } elseif (is_single()) {
            $barba_ns = 'single';
        } elseif (is_archive()) {
            $barba_ns = 'archive';
        }
        ?>
        <div class="barba-container<?php echo leapin_bg_image(); ?>"
             data-pjax_transition="<?php echo $inst->get(LEAPIN_IDs::$leapin_pjax_transition, LEAPIN_Theme_Mod::$default_leapin_pjax_transition); ?>"
             data-namespace="<?php echo $barba_ns; ?>">
            <div class="spinner-container">
                <div class="three-dots-spinner">
                    <div class="bounce1"></div>
                    <div class="bounce2"></div>
                    <div class="bounce3"></div>
                </div>
            </div>
            <?php $content_cls = "content-" . get_the_ID();
            $content_cls .= (is_front_page() || is_home()) ? " home" : "";
            ?>
            <div id="content" class="<?php echo $content_cls; ?>">
                <?php if (is_home() || is_front_page()): ?>
                    <?php echo LEAPIN_Custom_Header::getMedia(); ?>
                <?php endif; ?>
                <div id="above_container" class="above_container">
                    <!-- widget area for above container -->
                    <?php if (is_active_sidebar('above_container')) : ?>

                        <?php dynamic_sidebar('above_container'); ?>

                    <?php endif; ?>
                </div>
                <?php // display header when header style is "fullwidth" ?>
                <?php echo LEAPIN_Single_Tags::get_header('in_head'); ?>
                <!--Breadcrumb-->
                <?php
                if ((leapin_is_mod_visible(LEAPIN_IDs::$leapin_hide_breadcrumb) && is_singular())
                    || !is_singular()) {
                    LEAPIN_Breadcrumbs::show();
                }
                ?>
                <!--Breadcrumb end-->
                <div id="inner-content"
                     class="<?php echo LEAPIN_General_Settings::get_the_layout(); ?> inner-content leapin-wrap cf">
