<?php

/**
 * class LEAPIN_Breadcrumbs
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Breadcrumbs
{
    private static $separator = '/';
    private static $content_num = 1;

    public function __construct()
    {
    }

    /**
     * Show breadcrumbs
     */
    public static function show()
    {
        // Settings
//        $separator = '<i class="material-icons">keyboard_arrow_right</i>';
        $breadcrums_id = 'breadcrumbs';
        $breadcrums_class = 'breadcrumbs col-12';

        // If you have any custom post types with custom taxonomies, put the taxonomy name below (e.g. product_cat)
        $custom_taxonomy = 'product_cat';

        // Get the query & post information
        global $post, $wp_query;


        // Do not display on the homepage
        if (!(is_front_page() || is_home())) {

            // Build the breadcrums
            echo '<nav  id="' . $breadcrums_id . '" class="' . $breadcrums_class . '" aria-label="Breadcrumb navigation">';
            echo '<ol itemscope itemtype="http://schema.org/BreadcrumbList">';

            // Home page
            echo self::getListItem('home', 'Home', leapin_get_home_url());
            echo self::get_separator();

            if (is_archive() && is_tax() && !is_category() && !is_tag()) {

                // If post is a custom post type
                $post_type = get_post_type();

                // If it is a custom post type display name and link
                if ($post_type != 'post') {

                    $post_type_object = get_post_type_object($post_type);
                    $post_type_archive = get_post_type_archive_link($post_type);
                    $label = $post_type_object->labels->name;
                    echo self::getListItem('cat', $label, $post_type_archive);
                    echo self::get_separator();

                }

                $query_obj = get_queried_object();
                $custom_tax_name = $query_obj->name;
                $get_term_slug = $query_obj->slug;
                $taxonomy = $query_obj->taxonomy;
                $get_term_link = get_term_link($get_term_slug, $taxonomy);
                echo self::getListItem('current', $custom_tax_name, $get_term_link);

            } else if (is_single()) {

                // If post is a custom post type
                $post_type = get_post_type();

                // If it is a custom post type display name and link
                if ($post_type != 'post') {

                    $post_type_object = get_post_type_object($post_type);
                    $post_type_archive = get_post_type_archive_link($post_type);
                    $label =  $post_type_object->labels->name;
                    echo self::getListItem('cat', $label, $post_type_archive);

                    echo self::get_separator();

                }

                // Get post category info
                $category = get_the_category();

                if (!empty($category)) {

                    // get category id
                    $term_id = leapin_get_yoast_primary_category_id();
                    if (!$term_id) return;
                    // Loop through parent categories and store in variable $cat_display
                    $cat_display = '';
                    foreach (self::get_cat_breadcrumbs_link_array($term_id, self::$content_num) as $cat_link) {
                        $cat_display .= '<li class="item-cat" itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">' . $cat_link . '</li>';
                        $cat_display .= self::get_separator();

                    }
                }

                // If it's a custom post type within a custom taxonomy
                $taxonomy_exists = taxonomy_exists($custom_taxonomy);
                if (empty($term_id) && !empty($custom_taxonomy) && $taxonomy_exists) {

                    $taxonomy_terms = get_the_terms($post->ID, $custom_taxonomy);
                    if (!empty($taxonomy_terms)) {
                        $cat_id = $taxonomy_terms[0]->term_id;
                        $cat_nicename = $taxonomy_terms[0]->slug;
                        $cat_link = get_term_link($taxonomy_terms[0]->term_id, $custom_taxonomy);
                        $cat_name = $taxonomy_terms[0]->name;
                    }

                }

                $paged = get_query_var('page') ? sprintf(__(' (Page :%s)', 'pjax-blog'), get_query_var('page')) : '';

                // Check if the post is in a category
                if (!empty($term_id)) {
                    echo $cat_display;
                    $label = get_post_field('post_title', $post->ID, 'raw') . $paged;
                    echo self::getListItem('current', $label, leapin_get_permalink());

                    // Else if post is in a custom taxonomy
                } else if (!empty($cat_id)) {
                    echo self::getListItem('cat', $cat_name, $cat_link);
//                    echo '<li class="item-cat item-cat-' . $cat_id . ' item-cat-' . $cat_nicename . '" itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem"><a class="bread-cat bread-cat-' . $cat_id . ' bread-cat-' . $cat_nicename . '" href="' . $cat_link . '" title="' . $cat_name . '" itemprop="item"><span itemprop="name">' . $cat_name . '</span></a><meta itemprop="position" content="' . self::$content_num++ . '"/></li>';
                    echo self::get_separator();
                    $title = get_post_field('post_title', $post->ID, 'raw');
                    echo self::getListItem('current', $title, leapin_get_permalink());

                } else {
                    $title = get_post_field('post_title', $post->ID, 'raw');
                    echo self::getListItem('current', $title, leapin_get_permalink());

                }

            } else if (is_category()) {

                // Category page
                $cat_name = single_cat_title('', false);
                $cat_link = get_category_link(leapin_get_yoast_primary_category_id());
                echo self::getListItem('current', $cat_name, $cat_link);

            } else if (is_page()) {

                // Standard page
                if ($post->post_parent) {

                    // If child page, get parents
                    $anc = get_post_ancestors($post->ID);

                    // Get parents in the right order
                    $anc = array_reverse($anc);

                    // Parent page loop
                    if (!isset($parents)) $parents = null;
                    foreach ($anc as $ancestor) {
                        echo self::getListItem('parent', get_the_title($ancestor), leapin_get_permalink($ancestor));
                        $parents .= self::get_separator();
                    }

                    // Display parent pages
                    echo $parents;

                    // Current page
                    echo self::getListItem('current', get_post_field('post_title', $post->ID, 'raw'), leapin_get_permalink());

                } else {

                    // Just display current page if not parents
                    echo self::getListItem('current', get_post_field('post_title', $post->ID, 'raw'), leapin_get_permalink());

                }

            } else if (is_tag()) {

                // Get tag information
                $term_id = get_query_var('tag_id');
                $taxonomy = 'post_tag';
                $term = get_term_by('id', $term_id, $taxonomy);
                $get_term_id = $term->term_id;
                $get_term_slug = $term->slug;
                $get_term_name = $term->name;
                $get_term_link = get_term_link($get_term_slug, $taxonomy);
                // Display the tag name
                echo self::getListItem('current', $get_term_name, $get_term_link);

            } elseif (is_day()) {

                // Day archive

                // Year link
                echo self::getListItem('year', get_the_time('Y'), get_year_link(get_the_time('Y')));

//                echo '<li class="item-year item-year-' . get_the_time('Y') . '" itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link(get_the_time('Y')) . '" title="' . get_the_time('Y') . '" itemprop="item"><span itemprop="name">' . get_the_time('Y') . '</span></a><meta itemprop="position" content="' . self::$content_num++ . '"/></li>';
                echo self::get_separator();

                // Month link
                echo self::getListItem('month', get_the_time('m'), get_month_link(get_the_time('Y'), get_the_time('m')));
                echo self::get_separator();

                // Day display
                echo self::getListItem('current', get_the_time('j'), get_day_link(get_the_time('Y'), get_the_time('m'), get_the_time('j')));

            } else if (is_month()) {

                // Month Archive

                // Year link
                echo self::getListItem('year', get_the_time('Y'), get_year_link(get_the_time('Y')));

                echo self::get_separator();

                // Month link
                echo self::getListItem('month', get_the_time('m'), get_month_link(get_the_time('Y'), get_the_time('m')));

            } else if (is_year()) {

                // Year link
                echo self::getListItem('year', get_the_time('Y'), get_year_link(get_the_time('Y')));


            } else if (is_author()) {

                // Auhor archive

                // Get the author information
                global $author;
                $userdata = get_userdata($author);

                // Display author name
                echo self::getListItem('current', $userdata->display_name, $userdata->user_url);

            } else if (is_search()) {

                // Search results page
                // Display author name
                $title = "Search results for: " . get_search_query();
                echo self::getListItem('current', $title, get_search_query());

            } elseif (is_404()) {

                // 404 page
                echo self::getListItem('current', __('Page Not Found', 'pjax-blog'), home_url());
            }

            echo '</ol>';
            echo '</nav>';

        }

    }

    /**
     * Get multi-level category breadcrumb items
     *
     * @param $term_id
     * @param $content_num
     * @return array
     */
    private static function get_cat_breadcrumbs_link_array($term_id, &$content_num)
    {
        $link_array = array();
        $cat = get_category($term_id);
        $cat_name = $cat->name;
        $cat_link = get_category_link($term_id);
        $link_array[] = '<a class="bread-link bread-cat" href="' . $cat_link . '" title="' . $cat_name . '" itemprop="item"><span itemprop="name">' . $cat_name . '</span></a><meta itemprop="position" content="__content_num__"/>';
        while (1) {
            if (!$cat->parent) break;
            $cat = get_category($cat->parent);
            $cat_name = $cat->name;
            $cat_link = get_category_link($cat->term_id);
            $link_array[] = '<a class="bread-link bread-cat" href="' . $cat_link . '" title="' . $cat_name . '" itemprop="item"><span itemprop="name">' . $cat_name . '</span></a><meta itemprop="position" content="__content_num__"/>';
        }
        $link_array = array_reverse($link_array);
        foreach ($link_array as &$link) {
            $link = str_replace('__content_num__', $content_num++, $link);
        }
        return $link_array;
    }

    private static function get_separator()
    {
        return '<li class="separator" role="separator"> ' . self::$separator . ' </li>';
    }

    private static function getListItem($type, $title, $href)
    {
        $title = wp_strip_all_tags($title);
        $title = esc_html($title);
        $href = esc_url($href);
        return "<li class=\"item-$type\" itemprop=\"itemListElement\" itemscope itemtype=\"http://schema.org/ListItem\"><a class=\"bread-$type\" href=\"$href\" title=\"$title\" itemprop=\"item\"><span itemprop=\"name\">$title</span></a><meta itemprop=\"position\" content=\"" . self::$content_num++ . "\"/></li>";
    }
}
