<?php
/**
 * Customizer section with label
 *
 * Thanks to trt-customize-pro https://github.com/justintadlock/trt-customizer-pro
 * @since  1.6.10
 * @access public
 */
class LeapIn_With_Label_Section extends WP_Customize_Section {

	/**
	 * The type of customize section being rendered.
	 *
	 * @since  1.6.10
	 * @access public
	 * @var    string
	 */
	public $type = 'leapin-with-label-section';

	/**
	 * Custom button text to output.
	 *
	 * @since  1.6.10
	 * @access public
	 * @var    string
	 */
	public $label = '';

	/**
	 * Add custom parameters to pass to the JS via JSON.
	 *
	 * @since  1.6.10
	 * @access public
	 * @return void
	 */
	public function json() {
		$json = parent::json();

		$json['label'] = $this->label;

		return $json;
	}

	/**
	 * Outputs the Underscore.js template.
	 *
	 * @since  1.6.10
	 * @access public
	 * @return void
	 */
	protected function render_template() { ?>

        <li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }}">
            <h3 class="accordion-section-title" tabindex="0">
                {{ data.title }}
                <# if ( data.label ) { #>
                <span class="button button-primary alignright">{{ data.label }}</span>
                <# } #>
                <span class="screen-reader-text"><?php _e( 'Press return or enter to open this section', 'pjax-blog' ); ?></span>
            </h3>
            <ul class="accordion-section-content">
                <li class="customize-section-description-container section-meta <# if ( data.description_hidden ) { #>customize-info<# } #>">
                    <div class="customize-section-title">
                        <button class="customize-section-back" tabindex="-1">
                            <span class="screen-reader-text"><?php _e( 'Back', 'pjax-blog'  ); ?></span>
                        </button>
                        <h3>
							<span class="customize-action">
								{{{ data.customizeAction }}}
							</span>
                            {{ data.title }}
                        </h3>
                        <# if ( data.description && data.description_hidden ) { #>
                        <button type="button" class="customize-help-toggle dashicons dashicons-editor-help" aria-expanded="false"><span class="screen-reader-text"><?php _e( 'Help', 'pjax-blog'  ); ?></span></button>
                        <div class="description customize-section-description">
                            {{{ data.description }}}
                        </div>
                        <# } #>

                        <div class="customize-control-notifications-container"></div>
                    </div>

                    <# if ( data.description && ! data.description_hidden ) { #>
                    <div class="description customize-section-description">
                        {{{ data.description }}}
                    </div>
                    <# } #>
                </li>
            </ul>
        </li>
	<?php }
}
