<?php

/**
 * Theme footer module
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Footer
{

    public static $inst;
    public static $footer_options_added;

    public function __construct()
    {

        self::$footer_options_added = [];
        self::$inst = LEAPIN_Theme_Mod::get_instance();
        $this->registerActionHooks();
        return $this;
    }

    public function registerActionHooks()
    {

        add_action('widgets_init', array($this, 'registerWidgets'));
        add_action('customize_register', array($this, 'registerCustomizer'));
        add_filter('leapin_custom_css', array($this, 'set_bg_image_url'));
        add_filter('leapin_custom_css', array($this, 'set_footer_style'));
        return $this;
    }

    public function registerWidgets()
    {
        for ($i = 1; $i < 5; $i++) {
            register_sidebar(array(
                'name' => sprintf(esc_html__('Footer %s', 'pjax-blog'), $i),
                'id' => sprintf('footer-area-%s', $i),
                'description' => '',
                'before_widget' => '<aside id="%1$s" class="widget %2$s">',
                'after_widget' => '</aside>',
                'before_title' => '<h2 class="widget-title h6">',
                'after_title' => '</h2>',
            ));
        }
        return $this;
    }

    public function registerCustomizer($wp_customize)
    {

        $this->registerCustomizerSettings('footer', $wp_customize);

        return $this;
    }

    public function registerCustomizerSettings($file_handle = '', $wp_customize)
    {

        require_once get_template_directory() . '/inc/footer/customizer/' . sanitize_title($file_handle) . '.php';
        require_once get_template_directory() . '/inc/footer/customizer/' . sanitize_title($file_handle) . '-copyright.php';

        return $this;
    }

    public static function get_flex_basis()
    {
        $inst = LEAPIN_Theme_Mod::get_instance();
        $columns = $inst->get(LEAPIN_IDs::$leapin_footer_widget_columns, LEAPIN_Theme_Mod::$default_leapin_footer_widget_columns);

        $transport_columns = array(
            '1-columns' => 100,
            '2-columns' => 50,
            '3-columns' => 33,
            '4-columns' => 25
        );

        return $transport_columns[$columns];
    }

    public static function hide_column($pos)
    {
        $columns = self::$inst->get(LEAPIN_IDs::$leapin_footer_widget_columns, LEAPIN_Theme_Mod::$default_leapin_footer_widget_columns);

        $transport_columns = array(
            '1-columns' => 1,
            '2-columns' => 2,
            '3-columns' => 3,
            '4-columns' => 4
        );
        return $transport_columns[$columns] >= $pos ? true : false;
    }

    public static function set_bg_image_url($css)
    {
        $img = self::$inst->get(LEAPIN_IDs::$leapin_footer_bg_image);
        if (isset($img)) {
            $css .= "#leapin_footer{background-image: url($img);}";
        }
        return $css;
    }

    public function set_footer_style($css)
    {
        $css .= "@media only screen and (min-width: 1030px) {";
        for ($i = 1; $i < 5; $i++) {
            $footer_id = 'footer-area-' . $i;
            $border_color = self::$inst->get(LEAPIN_IDs::$leapin_footer_widget_border_color, '#484848');

            $type = self::$inst->get(LEAPIN_IDs::$leapin_footer_type . $i, LEAPIN_Theme_Mod::$default_leapin_footer_type);
            $width = self::$inst->get(LEAPIN_IDs::$leapin_footer_width . $i, self::get_flex_basis());
            $v_align = self::$inst->get(LEAPIN_IDs::$leapin_footer_v_align . $i, LEAPIN_Theme_Mod::$default_leapin_footer_v_align);
            $h_align = self::$inst->get(LEAPIN_IDs::$leapin_footer_h_align . $i, LEAPIN_Theme_Mod::$default_leapin_footer_h_align);
            // width and text align
            $css .= "#$footer_id{text-align: $h_align;flex-basis: $width%;}";
            $css .= "#$footer_id .widget-title{text-align: $h_align;}";

            // horizontal align
            if ($h_align === "center") {
                $css .= "#$footer_id{align-items: center;}";
                // defined in css file
            } elseif ($h_align === "left") {
                $css .= "#$footer_id{align-items: flex-start;}";
            } elseif ($h_align === "right") {
                $css .= "#$footer_id{align-items: flex-end;}";
            }

            // vertical align
            if ($v_align === "center") {
                $css .= "#$footer_id{justify-content: center;}";
            } elseif ($v_align === "top") {
                $css .= "#$footer_id{justify-content: flex-start;}";
            } elseif ($v_align === "bottom") {
                $css .= "#$footer_id{justify-content: flex-end;}";
            }

            // design type
            if ($type === "h_line") {
                $css .= "#$footer_id .widget-title::before{background-color:$border_color;}";
                if ($h_align === "center") {
                    // defined in css file
                } elseif ($h_align === "right") {
                    $css .= "#$footer_id .widget-title::before{left: 100%;transform: translateX(-100%);}";
                } elseif ($h_align === "left") {
                    $css .= "#$footer_id .widget-title::before{left: 0;transform:translateX(0);}";
                }
            } elseif ($type === "v_line") {
                $css .= "#$footer_id .widget-title::before{content: none;}";
                $css .= "#$footer_id .widget-title{margin-bottom: 0;padding-bottom: .3rem;}";
                $css .= "#$footer_id .widget > *:not(.widget-title){padding: 0 1rem;}";
                $css .= "#$footer_id .widget > *:not(.widget-title){border-left:$border_color 1px solid;}";

            } elseif ($type === "simple") {
                $css .= "#$footer_id .widget-title::before{content: none;}";
                $css .= "#$footer_id .widget-title{margin-bottom: 0;padding-bottom: .3rem;}";
            }
            $css .= "#$footer_id .widget-title::before{text-align: $h_align;}";
        }
//        }
        $css .= "}";
        return $css;
    }
}

new LEAPIN_Footer();
