<?php

/**
 * class LEAPIN_General_Settings
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_General_Settings
{

    public static $leapin_mods;

    public function __construct()
    {
        self::$leapin_mods = LEAPIN_Theme_Mod::get_instance();
        $this->registerActionHooks();
        return $this;

    }

    public function registerActionHooks()
    {

        add_action('customize_register', array($this, 'registerCustomizer'));
        add_action('leapin_add_script_properties', array($this, 'setScriptPjaxTransitions'));
        return $this;

    }


    public function registerCustomizer($wp_customize)
    {

        $wp_customize->add_panel('leapin_settings', array(
            'title' => __('Pjax Blog Settings', 'pjax-blog'),
            'priority' => 1, // Mixed with top-level-section hierarchy.
        ));
        $this->registerCustomizerSettings('pjax/options', $wp_customize);
        $this->registerCustomizerSettings('layout', $wp_customize);
        $this->registerCustomizerSettings('profile', $wp_customize);
        $this->registerCustomizerSettings('widget', $wp_customize);
        $this->registerCustomizerSettings('other', $wp_customize);
        $this->registerCustomizerSettings('speed-optimization', $wp_customize);
        $this->registerCustomizerSettings('help', $wp_customize);

        return $this;
    }

    public function registerCustomizerSettings($file_handle = '', $wp_customize)
    {

        require_once get_template_directory() . '/inc/general-settings/' . $file_handle . '.php';

        return $this;
    }

    public static function get_the_layout()
    {

        $mod_home = self::$leapin_mods->get(LEAPIN_IDs::$leapin_layouts_home, LEAPIN_Theme_Mod::$default_leapin_layouts_home);
        $mod_general = self::$leapin_mods->get(LEAPIN_IDs::$leapin_layouts_general, LEAPIN_Theme_Mod::$default_leapin_layouts_general);

        if ((is_home() || is_front_page()) && $mod_home != LEAPIN_Theme_Mod::$default_leapin_layouts_home) {
            $layout = $mod_home;

        } elseif (is_singular() && (!empty(self::leapin_get_layout_single()) && self::leapin_get_layout_single() != 'default')) {
            $layout = self::leapin_get_layout_single();

        } else {
            $layout = $mod_general;
        }

        return apply_filters('leapin_the_layout', $layout, LEAPIN_Theme_Mod::$choice_leapin_layouts_each_page);
    }

    public static function leapin_get_layout_single()
    {
        return leapin_get_post_meta( LEAPIN_IDs::$leapin_layouts_single_key );
    }

    public static function get_sns_links()
    {
        $urls = LEAPIN_Single_Tags::get_org_sns_urls();
        $echo = LEAPIN_Single_Tags::get_sns_links($urls);
        return $echo;
    }

    public function setScriptPjaxTransitions($MODs)
    {

        // set pjax transition
        $pjax_key = LEAPIN_IDs::$leapin_pjax_transition;
        $default = LEAPIN_Theme_Mod::$default_leapin_pjax_transition;
        $this->setPjaxTransitions($pjax_key, $default, $MODs);

        // set pjax fallback transition
        $pjax_key = LEAPIN_IDs::$leapin_pjax_transition_fallback;
        $default = LEAPIN_Theme_Mod::$default_leapin_pjax_transition_fallback;
        $this->setPjaxTransitions($pjax_key, $default,$MODs);

        return $MODs;
    }

    private function setPjaxTransitions($mods_id, $default, &$MODs)
    {
        $MODs[$mods_id] = [];

        $transitions = self::getPjaxTransitions();

        $selected = LEAPIN_Theme_Mod::get_instance()
            ->get($mods_id, $default);

        // if fallback transition is not set.
        if($mods_id === LEAPIN_IDs::$leapin_pjax_transition_fallback && (!$selected || $selected === '0'))
            return;


        $random_transition = LEAPIN_Theme_Mod::get_instance()
            ->get(LEAPIN_IDs::$leapin_pjax_random_transition_in_group, false);

        if ($random_transition) {
            if(array_key_exists($selected, $transitions)){
                $group_id = $transitions[$selected]['group'];
            }else{
                $group_id = $transitions[$default]['group'];
            }

            foreach ($transitions as $key => $val) {
                if ($group_id === $val['group']) {
                    $MODs[$mods_id][] = $val;
                }
            }
        } else {
            $MODs[$mods_id][] = $transitions[$selected];
        }
    }

    /**
     * return pjax transition patterns
     *
     * @return array
     * @since 1.7.0
     */
    public static function getPjaxTransitions(){
        return apply_filters('leapin_pjax_transitions', [
            '1' => ['fallback' => true, 'group' => '1', 'name' => 'Move to left/ from right', 'outClass' => 'pt-page-moveToLeft', 'inClass' => 'pt-page-moveFromRight'],
            '2' => ['fallback' => true, 'group' => '1', 'name' => 'Move to right/ from left', 'outClass' => 'pt-page-moveToRight', 'inClass' => 'pt-page-moveFromLeft'],
            '3' => ['fallback' => true, 'group' => '1', 'name' => 'Move to top/ from bottom', 'outClass' => 'pt-page-moveToTop', 'inClass' => 'pt-page-moveFromBottom'],
            '4' => ['fallback' => true, 'group' => '1', 'name' => 'Move to bottom/ from top', 'outClass' => 'pt-page-moveToBottom', 'inClass' => 'pt-page-moveFromTop'],
            '5' => ['fallback' => true, 'group' => '2', 'name' => 'Fade / from right', 'outClass' => 'pt-page-fade', 'inClass' => 'pt-page-moveFromRight pt-page-ontop'],
            '6' => ['fallback' => true, 'group' => '2', 'name' => 'Fade / from left', 'outClass' => 'pt-page-fade', 'inClass' => 'pt-page-moveFromLeft pt-page-ontop'],
            '7' => ['fallback' => true, 'group' => '2', 'name' => 'Fade / from bottom', 'outClass' => 'pt-page-fade', 'inClass' => 'pt-page-moveFromBottom pt-page-ontop'],
            '8' => ['fallback' => true, 'group' => '2', 'name' => 'Fade / from top', 'outClass' => 'pt-page-fade', 'inClass' => 'pt-page-moveFromTop pt-page-ontop'],
            '13' => ['fallback' => true, 'group' => '4', 'name' => 'Different easing / from right', 'outClass' => 'pt-page-moveToLeftEasing pt-page-ontop', 'inClass' => 'pt-page-moveFromRight'],
            '14' => ['fallback' => true, 'group' => '4', 'name' => 'Different easing / from left', 'outClass' => 'pt-page-moveToRightEasing pt-page-ontop', 'inClass' => 'pt-page-moveFromLeft'],
            '15' => ['fallback' => true, 'group' => '4', 'name' => 'Different easing / from bottom', 'outClass' => 'pt-page-moveToTopEasing pt-page-ontop', 'inClass' => 'pt-page-moveFromBottom'],
            '16' => ['fallback' => true, 'group' => '4', 'name' => 'Different easing / from top', 'outClass' => 'pt-page-moveToBottomEasing pt-page-ontop', 'inClass' => 'pt-page-moveFromTop'],
        ]);
    }

    /**
     * return pjax fallback transition patterns
     *
     * @return array
     * @since 1.7.0
     */
    public static function getPjaxTransitionsFallback(){
        $ret = [];
        $transitions = self::getPjaxTransitions();
        foreach ($transitions as $key => $val) {
            if (true === $val['fallback']) {
                $ret[$key] = $val;
            }
        }
        return $ret;
    }

}

new LEAPIN_General_Settings();
