<?php
/**
 * Widget Additional Setting
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
$panel = 'leapin_settings';
$section = 'leapin_widget_section';

$wp_customize->add_section( $section, array(
	'title' => __( 'Widget / Widget Area', 'pjax-blog' ),
    'panel' => $panel,
	'description' => __( 'Set desired widget option as you like.', 'pjax-blog' ),
	'priority' => 60,
	'capability' => 'edit_theme_options',
));

/**
 * [Pjax Blog] Blog Posts Section
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_widget_rich_post_heading, array(
    'type' => 'theme_mod', // or 'option'
    'sanitize_callback' => 'leapin_sanitize_mock',
));
$wp_customize->add_control(new LEAPIN_Heading_Larger_Customize_Control($wp_customize, LEAPIN_IDs::$leapin_widget_rich_post_heading, array(
    'settings' => LEAPIN_IDs::$leapin_widget_rich_post_heading,
    'label' => __('[Pjax Blog] Blog Posts Widget Options', 'pjax-blog'),
    'section' => $section,
)));

/**
 * Post Border Radius
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_widget_post_border_radius, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'default' => LEAPIN_Theme_Mod::$default_leapin_widget_post_border_radius,
    'sanitize_callback' => 'leapin_sanitize_number',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_widget_post_border_radius, array(
    'label' => __('Blog Post Border Radius(px):', 'pjax-blog'),
    'section' => $section,
    'type' => 'number',
));

/**
 * Thumbnail Border Radius
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_widget_thumb_border_radius, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'default' => LEAPIN_Theme_Mod::$default_leapin_widget_thumb_border_radius,
    'sanitize_callback' => 'leapin_sanitize_number',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_widget_thumb_border_radius, array(
    'label' => __('Blog Post Thumbnail Border Radius(px):', 'pjax-blog'),
    'section' => $section,
    'type' => 'number',
));

/**
 * Read More Label
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_widget_post_read_more_label, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'default' => LEAPIN_Theme_Mod::$default_leapin_widget_post_read_more_label,
    'sanitize_callback' => 'leapin_sanitize_text',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_widget_post_read_more_label, array(
    'label' => __('Default Read More Label', 'pjax-blog'),
    'section' => $section,
    'description' => __( 'Set default Read More Label of Each Post. It will apply for the button label inputs of Edit Page of new Post.', 'pjax-blog' ),
    'type' => 'text',
));

/**
 * More Post Label
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_widget_post_more_label, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'default' => __('More', 'pjax-blog'),
    'sanitize_callback' => 'leapin_sanitize_text',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_widget_post_more_label, array(
    'label' => __('More Label', 'pjax-blog'),
    'section' => $section,
    'description' => __( 'Set the label of the button to fetch more posts.', 'pjax-blog' ),
    'type' => 'text',
));

/**
 * Widget Area Options
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_widget_widget_area_heading, array(
    'type' => 'theme_mod', // or 'option'
    'sanitize_callback' => 'leapin_sanitize_mock',
));
$wp_customize->add_control(new LEAPIN_Heading_Larger_Customize_Control($wp_customize, LEAPIN_IDs::$leapin_widget_widget_area_heading, array(
    'settings' => LEAPIN_IDs::$leapin_widget_widget_area_heading,
    'label' => __('Widget Area Options', 'pjax-blog'),
    'section' => $section,
)));

/**
 * Above Container Background Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_widget_above_container_bg, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));

$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_widget_above_container_bg, array(
    'label' => __('Above Container Background Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_widget_above_container_bg,
    'show_opacity'  => true,
)));

/**
 * Below Container Background Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_widget_below_container_bg, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));

$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_widget_below_container_bg, array(
    'label' => __('Below Container Background Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_widget_below_container_bg,
    'show_opacity'  => true,
)));