<?php
/**
 * Single Setting
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
$panel = 'leapin_settings';
$section = 'leapin_single_section';
LEAPIN_IDs::initPriority();

$wp_customize->add_section($section, array(
    'title' => __('Single Post/Page', 'pjax-blog'),
    'description' => '<em>' . __('This section handles the all default settings for your single post page. Change it to your preference.', 'pjax-blog') . '</em>', // Include html tags such as <p>.
    'priority' => 40,
    'panel' => $panel,
));

/**
 * Select Headlines Style
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_single_headlines_style, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => LEAPIN_Theme_Mod::$default_leapin_single_headlines_style,
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'leapin_sanitize_text',
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_single_headlines_style, array(
    'type' => 'select',
    'label' => __('Select Default Headlines Style', 'pjax-blog'),
    'section' => $section,
    'choices' => LEAPIN_Theme_Mod::$choice_leapin_single_headlines_style,
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Single default Image.
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_single_default_image, array(
    'type' => 'theme_mod',
    'capability' => 'manage_options',
    'default' => esc_url(LEAPIN_Theme_Mod::$default_leapin_single_default_image),
    'transport' => LEAPIN_IDs::$refresh,
    'sanitize_callback' => 'esc_url_raw',
));

$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, LEAPIN_IDs::$leapin_single_default_image,
    array(
        'label' => __('Default Featured Image', 'pjax-blog'),
        'section' => $section,
        'settings' => LEAPIN_IDs::$leapin_single_default_image,
        'description' => 'Applied for featured Image when it\'s not set.',
        'priority' => LEAPIN_IDs::getPriority()
    )
));

/**
 * label on share button group in Single Page
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_single_sns_message_label, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$refresh,
    'default' => LEAPIN_Theme_Mod::$default_leapin_single_sns_message_label,
    'sanitize_callback' => 'leapin_sanitize_text',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_single_sns_message_label, array(
    'settings' => LEAPIN_IDs::$leapin_single_sns_message_label,
    'label' => __('Label on SNS button group below Content', 'pjax-blog'),
    'section' => $section,
    'type' => 'text',
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Select items which you want to hide.
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_single_heading_hide_section, array(
    'type' => 'theme_mod', // or 'option'
    'sanitize_callback' => 'leapin_sanitize_mock',
));
$wp_customize->add_control(new LEAPIN_Heading_Customize_Control($wp_customize, LEAPIN_IDs::$leapin_single_heading_hide_section, array(
    'settings' => LEAPIN_IDs::$leapin_single_heading_hide_section,
    'label' => __('Select Items to Hide', 'pjax-blog'),
    'section' => $section,
    'description' => __('Select Items which you want to hide.', 'pjax-blog'),
    'priority' => LEAPIN_IDs::getPriority()
)));

/**
 * Hide Breadcrumb below Content
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_hide_breadcrumb, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_checkbox'
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_hide_breadcrumb, array(
    'settings' => LEAPIN_IDs::$leapin_hide_breadcrumb,
    'label' => __('Hide Breadcrumb', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Hide Author Name Below Title
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_hide_author_name_below_title, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$postMessage,
    'default' => false,
    'sanitize_callback' => 'leapin_sanitize_checkbox',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_hide_author_name_below_title, array(
    'settings' => LEAPIN_IDs::$leapin_hide_author_name_below_title,
    'label' => __('Hide Author Name Below Title', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Hide Author Section Below Content
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_hide_author_section_below_content, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$postMessage,
    'default' => false,
    'sanitize_callback' => 'leapin_sanitize_checkbox',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_hide_author_section_below_content, array(
    'settings' => LEAPIN_IDs::$leapin_hide_author_section_below_content,
    'label' => __('Hide Author Section Below Content', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Hide Publish Date Below Title
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_hide_modified_date_below_title, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_checkbox',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_hide_modified_date_below_title, array(
    'settings' => LEAPIN_IDs::$leapin_hide_modified_date_below_title,
    'label' => __('Hide Modified Date Below Title', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Hide Category Term Below Title
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_hide_category_below_title, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_checkbox',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_hide_category_below_title, array(
    'settings' => LEAPIN_IDs::$leapin_hide_category_below_title,
    'label' => __('Hide Category Term Below Title', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Hide Category Term below Content
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_hide_category_below_content, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_checkbox',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_hide_category_below_content, array(
    'settings' => LEAPIN_IDs::$leapin_hide_category_below_content,
    'label' => __('Hide Category Term below Content', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Hide Tag Term below Content
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_hide_tag_below_content, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_checkbox',
));

$wp_customize->add_control(LEAPIN_IDs::$leapin_hide_tag_below_content, array(
    'settings' => LEAPIN_IDs::$leapin_hide_tag_below_content,
    'label' => __('Hide Tag Term below Content', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Hide Pagination Below Article
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_hide_pagination_below_article, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_checkbox',
));
$wp_customize->add_control(LEAPIN_IDs::$leapin_hide_pagination_below_article, array(
    'settings' => LEAPIN_IDs::$leapin_hide_pagination_below_article,
    'label' => __('Hide Prev/Next Pagenation Below Article', 'pjax-blog'),
    'section' => $section,
    'type' => 'checkbox',
    'priority' => LEAPIN_IDs::getPriority()
));

/**
 * Title Background Color
 */
$wp_customize->add_setting($setting_id = LEAPIN_IDs::$leapin_single_title_bg_color, array(
    'type' => 'theme_mod', // or 'option'
    'capability' => 'manage_options',
    'default' => '',
    'transport' => LEAPIN_IDs::$postMessage,
    'sanitize_callback' => 'leapin_sanitize_rgba_color'
));
$wp_customize->add_control(new LEAPIN_Customize_Alpha_Color_Control($wp_customize, LEAPIN_IDs::$leapin_single_title_bg_color, array(
    'label' => __('Title Background Color', 'pjax-blog'),
    'section' => $section,
    'settings' => LEAPIN_IDs::$leapin_single_title_bg_color,
    'show_opacity' => true,
    'priority' => LEAPIN_IDs::getPriority()
)));



