<?php
/**
 * Class LEAPIN_On_Header_Image
 *
 * @author LeapIn Corp.
 * @since 1.1.0
 */
class LEAPIN_On_Header_Image extends WP_Widget
{
    /**
     * Sets up a new Pjax Blog On Header Image widget instance.
     *
     * @since 1.1.0
     */
    public function __construct()
    {
        $widget_ops = array(
            'classname' => 'leapin-on-header-image',
            'description' => __('Your site&#8217;s Widget For On Header Image Widget Area', 'pjax-blog'),
            'customize_selective_refresh' => true,
        );
        parent::__construct('leapin-on-header-image', __('[Pjax Blog] On Header Image Widget', 'pjax-blog'), $widget_ops);
        $this->alt_option_name = 'leapin_widget_on_header_image';
    }

    /**
     * Outputs the content for the current Pjax Blog On Header Image widget instance.
     *
     * @since 1.1.0
     *
     * @param array $args Display arguments including 'before_title', 'after_title',
     *                        'before_widget', and 'after_widget'.
     * @param array $instance Settings for the current Pjax Blog widget instance.
     */
    public function widget($args, $instance)
    {
        if (!isset($args['widget_id'])) {
            $args['widget_id'] = $this->id;
        }

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : false;
        $desc = ( ! empty( $instance['desc'] ) ) ? $instance['desc'] : false;
        $link = ( ! empty( $instance['link'] ) ) ? $instance['link'] : false;
        $url = ( ! empty( $instance['url'] ) ) ? $instance['url'] : false;

        $echo = $args['before_widget'];
        if ( $title ) {
            $echo .= $args['before_title'] . $title . $args['after_title'];
        }
        if ( $desc ) {
            $echo .= "<div class='desc'>$desc</div>";
        }
        if ( $link && $url) {
            $echo .= "<a class='flat_btn box-shadow' href='$url'>$link</a>";
        }

        $echo .=  $args['after_widget'];
        echo $echo;
    }

    /**
     * Handles updating the settings for the current Pjax Blog widget instance.
     *
     * @since 1.1.0
     *
     * @param array $new_instance New settings for this instance as input by the user via
     *                            WP_Widget::form().
     * @param array $old_instance Old settings for this instance.
     * @return array Updated settings to save.
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = leapin_sanitize_text($new_instance['title']);
        $instance['desc'] = wp_kses_post($new_instance['desc']);
        $instance['link'] = wp_kses_post($new_instance['link']);
        $instance['url'] = esc_url_raw($new_instance['url']);
        return $instance;
    }

    /**
     * Outputs the settings form for the Pjax Blog widget.
     *
     * @since 1.1.0
     *
     * @param array $instance Current settings.
     */
    public function form($instance)
    {
        ?>
        <p style="margin: 1em 0;"><?php _e('Please use this widget in <code>On Header Image widget area</code>.', 'pjax-blog')?><?php printf(__('Please set <a href="%s" target="_blank">Header Image</a> in advance.','pjax-blog'), leapin_get_customizer_sec_url('header_image'));?></p>
        <?php
        leapin_add_text_to_widget_form($this, $instance, 'title', [
            'label' => __('Title:', 'pjax-blog'),
        ]);
        leapin_add_text_to_widget_form($this, $instance, 'desc', [
            'label' => __('Content:', 'pjax-blog'),
        ]);
        leapin_add_text_to_widget_form($this, $instance, 'link', [
            'label' => __('Link Label:', 'pjax-blog'),
        ]);
        leapin_add_text_to_widget_form($this, $instance, 'url', [
            'type' => 'url',
            'label' => __('Link Url:', 'pjax-blog')
        ]);
    }
}

register_widget('LEAPIN_On_Header_Image');
