<?php

/**
 * Class LEAPIN_Widget_Posts
 *
 * @author LeapIn Corp.
 * @since 1.0.0
 */
class LEAPIN_Widget_Posts extends WP_Widget
{
    /**
     * Sets up a new Pjax Blog Post widget instance.
     *
     * @since 1.0.0
     */
    public function __construct()
    {
        $widget_ops = array(
            'classname' => 'leapin-blog-posts',
            'description' => __('Your site&#8217;s Beautiful Posts', 'pjax-blog'),
            'customize_selective_refresh' => true,
        );
        parent::__construct('leapin-blog-posts', __('[Pjax Blog] Blog Posts', 'pjax-blog'), $widget_ops);
        $this->alt_option_name = 'leapin_widget_entries';
    }

    /**
     * Outputs the content for the current Pjax Blog Post widget instance.
     *
     * @since 1.0.0
     *
     * @param array $args Display arguments including 'before_title', 'after_title',
     *                        'before_widget', and 'after_widget'.
     * @param array $instance Settings for the current Pjax Blog widget instance.
     */
    public function widget($args, $instance)
    {
        if (!isset($args['widget_id'])) {
            $args['widget_id'] = $this->id;
            $instance['widget_args'] = $args;
        }

        $cq = new LEAPIN_Query_Posts($instance, $args);
        $cq->ajax_or_print();

    }

    /**
     * Handles updating the settings for the current Pjax Blog widget instance.
     *
     * @since 1.0.0
     *
     * @param array $new_instance New settings for this instance as input by the user via
     *                            WP_Widget::form().
     * @param array $old_instance Old settings for this instance.
     * @return array Updated settings to save.
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = leapin_sanitize_text($new_instance['title']);
        $instance['theme_color'] = leapin_sanitize_rgba_color($new_instance['theme_color']);
        $instance['posts_per_page'] = (int)$new_instance['posts_per_page'];
        $instance['show_date'] = leapin_sanitize_widget_checkbox($new_instance, 'show_date');
        $instance['related_post'] = leapin_sanitize_widget_checkbox($new_instance, 'related_post');
        $instance['show_view_count'] = leapin_sanitize_widget_checkbox($new_instance, 'show_view_count');
        $instance['show_taxonomy'] = leapin_sanitize_text($new_instance['show_taxonomy']);
        $instance['post_type'] = leapin_sanitize_text($new_instance['post_type']);
        $instance['ajax_on_load_call'] = leapin_sanitize_widget_checkbox($new_instance, 'ajax_on_load_call');
        $instance['layout_type'] = leapin_sanitize_text($new_instance['layout_type']);
        $instance['taxonomy'] = leapin_sanitize_text($new_instance['taxonomy']);
        $instance['term_ids_or_slugs'] = leapin_sanitize_text($new_instance['term_ids_or_slugs']);
        $instance['custom_fields'] = leapin_sanitize_text($new_instance['custom_fields']);
        $instance['post_ids'] = leapin_sanitize_text($new_instance['post_ids']);
        $instance['exclude_post_ids'] = leapin_sanitize_text($new_instance['exclude_post_ids']);
        $instance['order_by'] = leapin_sanitize_text($new_instance['order_by']);
        $instance['grayscale'] = leapin_sanitize_text($new_instance['grayscale']);

        return $instance;
    }

    /**
     * Outputs the settings form for the Pjax Blog widget.
     *
     * @since 1.0.0
     *
     * @param array $instance Current settings.
     */
    public function form($instance)
    {

        leapin_add_text_to_widget_form($this, $instance, 'title', [
            'label' => __('Title:', 'pjax-blog')
        ]);

        /**
         * Display Options
         */
        leapin_add_large_title_to_widget_form(__('Display options', 'pjax-blog'));

        leapin_add_select_to_widget_form($this, $instance, 'layout_type', [
            'label' => __('Layout:', 'pjax-blog'),
            'choice' => LEAPIN_Query_Params::$layout_type
        ]);

        leapin_add_number_to_widget_form($this, $instance, 'posts_per_page', [
            'label' => __('Number of posts to show:', 'pjax-blog'),
            'min' => 0,
            'default' => 5
        ]);

        leapin_add_checkbox_to_widget_form($this, $instance, 'show_date', [
            'label' => __('Display post date?', 'pjax-blog')
        ]);

        if(leapin_is_bundle()) :
            leapin_add_checkbox_to_widget_form($this, $instance, 'show_view_count', [
                'label' => __('Display post view count?', 'pjax-blog')
            ]);
        endif;

        leapin_add_number_to_widget_form($this, $instance, 'grayscale', [
            'label' => __('Thumbnail overlay grayscale(0 - 100%):', 'pjax-blog'),
            'min' => 0,
            'max' => 100,
            'default' => 30
        ]);

        leapin_add_select_to_widget_form($this, $instance, 'show_taxonomy', [
            'label' => __('Show Type of Taxonomy Link:', 'pjax-blog'),
            'choice' => LEAPIN_Query_Params::$taxonomy,
            'add_empty' => true
        ]);

        leapin_add_select_to_widget_form($this, $instance, 'order_by', [
            'label' => __('Order by:', 'pjax-blog'),
            'choice' => LEAPIN_Query_Params::$order_by
        ]);

        leapin_add_color_picker_to_widget_form($this, $instance, 'theme_color', [
            'label' => __('Widget Theme Color:', 'pjax-blog')
        ]);
        ?>
        <p style="margin: 1em 0;">Please set other <a href="<?php echo leapin_get_customizer_sec_url('leapin_widget_section');?>" target="_blank"><?php _e('global variables','pjax-blog'); ?></a> to decorate this widget.</p>
        <?php
        /**
         * Filter Options
         */
        leapin_add_large_title_to_widget_form(__('Filter options', 'pjax-blog'));

        $choice = array_merge(LEAPIN_Query_Params::$post_type, ["any" => __('Any (may slow down page load speed)', 'pjax-blog')]);
        leapin_add_select_to_widget_form($this, $instance, 'post_type', [
            'label' => __('Post Type:', 'pjax-blog'),
            'choice' => $choice
        ]);

        leapin_add_select_to_widget_form($this, $instance, 'taxonomy', [
            'label' => __('Taxonomy:', 'pjax-blog'),
            'choice' => LEAPIN_Query_Params::$taxonomy
        ]);

        leapin_add_checkbox_to_widget_form($this, $instance, 'related_post', [
            'label' => __('Display posts related to tags, categories of the page?', 'pjax-blog')
        ]);

        leapin_add_text_to_widget_form($this, $instance, 'term_ids_or_slugs', [
            'label' => __('Terms IDs or Slugs(comma separated):', 'pjax-blog')
        ]);

        leapin_add_text_to_widget_form($this, $instance, 'custom_fields', [
            'label' => __('Custom Fields(key=value1,value2,..):', 'pjax-blog')
        ]);

        leapin_add_text_to_widget_form($this, $instance, 'post_ids', [
            'label' => __('Post IDs(comma separated):', 'pjax-blog')
        ]);

        leapin_add_text_to_widget_form($this, $instance, 'exclude_post_ids', [
            'label' => __('Exclude post IDs(comma separated):', 'pjax-blog')
        ]);

        /**
         * Other options
         */
        leapin_add_large_title_to_widget_form(__('Other options', 'pjax-blog'));

        leapin_add_checkbox_to_widget_form($this, $instance, 'ajax_on_load_call', [
            'label' => __('Get post with ajax?', 'pjax-blog')
        ]);
    }
}

register_widget('LEAPIN_Widget_Posts');
